==> redux-form-6.7.0.jar: META-INF/resources/webjars/redux-form/6.7.0/es/index.js <==
import * as _actions from './actions';
export { default as defaultShouldAsyncValidate } from './defaultShouldAsyncValidate';
export { default as defaultShouldValidate } from './defaultShouldValidate';
export { default as Form } from './Form';
export { default as FormSection } from './FormSection';
export { default as SubmissionError } from './SubmissionError';
export { default as propTypes, fieldInputPropTypes, fieldMetaPropTypes, fieldPropTypes } from './propTypes';
export { default as Field } from './Field';
export { default as Fields } from './Fields';
export { default as FieldArray } from './FieldArray';
export { default as formValueSelector } from './formValueSelector';
export { default as getFormNames } from './getFormNames';
export { default as getFormValues } from './getFormValues';
export { default as getFormInitialValues } from './getFormInitialValues';
export { default as getFormSyncErrors } from './getFormSyncErrors';
export { default as getFormMeta } from './getFormMeta';
export { default as getFormAsyncErrors } from './getFormAsyncErrors';
export { default as getFormSyncWarnings } from './getFormSyncWarnings';
export { default as getFormSubmitErrors } from './getFormSubmitErrors';
export { default as isDirty } from './isDirty';
export { default as isInvalid } from './isInvalid';
export { default as isPristine } from './isPristine';
export { default as isValid } from './isValid';
export { default as isSubmitting } from './isSubmitting';
export { default as hasSubmitSucceeded } from './hasSubmitSucceeded';
export { default as hasSubmitFailed } from './hasSubmitFailed';
export { default as reduxForm } from './reduxForm';
export { default as reducer } from './reducer';
export { default as values } from './values';
import * as _actionTypes from './actionTypes';
export var actionTypes = _actionTypes;
export var actions = _actions;
var arrayInsert = _actions.arrayInsert,
    arrayMove = _actions.arrayMove,
    arrayPop = _actions.arrayPop,
    arrayPush = _actions.arrayPush,
    arrayRemove = _actions.arrayRemove,
    arrayRemoveAll = _actions.arrayRemoveAll,
    arrayShift = _actions.arrayShift,
    arraySplice = _actions.arraySplice,
    arraySwap = _actions.arraySwap,
    arrayUnshift = _actions.arrayUnshift,
    autofill = _actions.autofill,
    blur = _actions.blur,
    change = _actions.change,
    clearSubmitErrors = _actions.clearSubmitErrors,
    destroy = _actions.destroy,
    focus = _actions.focus,
    initialize = _actions.initialize,
    registerField = _actions.registerField,
    reset = _actions.reset,
    setSubmitFailed = _actions.setSubmitFailed,
    setSubmitSucceeded = _actions.setSubmitSucceeded,
    startAsyncValidation = _actions.startAsyncValidation,
    startSubmit = _actions.startSubmit,
    stopAsyncValidation = _actions.stopAsyncValidation,
    stopSubmit = _actions.stopSubmit,
    submit = _actions.submit,
    touch = _actions.touch,
    unregisterField = _actions.unregisterField,
    untouch = _actions.untouch;
export { arrayInsert, arrayMove, arrayPop, arrayPush, arrayRemove, arrayRemoveAll, arrayShift, arraySplice, arraySwap, arrayUnshift, autofill, blur, change, clearSubmitErrors, destroy, focus, initialize, registerField, reset, setSubmitFailed, setSubmitSucceeded, startAsyncValidation, startSubmit, stopAsyncValidation, stopSubmit, submit, touch, unregisterField, untouch };

==> redux-form-6.8.0.jar: META-INF/resources/webjars/redux-form/6.8.0/es/index.js <==
import * as _actions from './actions';
import * as _actionTypes from './actionTypes';
export { default as defaultShouldAsyncValidate } from './defaultShouldAsyncValidate';
export { default as defaultShouldValidate } from './defaultShouldValidate';
export { default as Form } from './Form';
export { default as FormSection } from './FormSection';
export { default as SubmissionError } from './SubmissionError';
// alias for propTypes
export { default as propTypes, fieldInputPropTypes, fieldMetaPropTypes, fieldPropTypes, formPropTypes } from './propTypes';
export { default as Field } from './Field';
export { default as Fields } from './Fields';
export { default as FieldArray } from './FieldArray';
export { default as formValueSelector } from './formValueSelector';
export { default as formValues } from './formValues';
export { default as getFormNames } from './getFormNames';
export { default as getFormValues } from './getFormValues';
export { default as getFormInitialValues } from './getFormInitialValues';
export { default as getFormSyncErrors } from './getFormSyncErrors';
export { default as getFormMeta } from './getFormMeta';
export { default as getFormAsyncErrors } from './getFormAsyncErrors';
export { default as getFormSyncWarnings } from './getFormSyncWarnings';
export { default as getFormSubmitErrors } from './getFormSubmitErrors';
export { default as isDirty } from './isDirty';
export { default as isInvalid } from './isInvalid';
export { default as isPristine } from './isPristine';
export { default as isValid } from './isValid';
export { default as isSubmitting } from './isSubmitting';
export { default as hasSubmitSucceeded } from './hasSubmitSucceeded';
export { default as hasSubmitFailed } from './hasSubmitFailed';
export { default as reduxForm } from './reduxForm';
export { default as reducer } from './reducer';
export { default as values } from './values';
export var actionTypes = _actionTypes;
export var actions = _actions;
var arrayInsert = _actions.arrayInsert,
    arrayMove = _actions.arrayMove,
    arrayPop = _actions.arrayPop,
    arrayPush = _actions.arrayPush,
    arrayRemove = _actions.arrayRemove,
    arrayRemoveAll = _actions.arrayRemoveAll,
    arrayShift = _actions.arrayShift,
    arraySplice = _actions.arraySplice,
    arraySwap = _actions.arraySwap,
    arrayUnshift = _actions.arrayUnshift,
    autofill = _actions.autofill,
    blur = _actions.blur,
    change = _actions.change,
    clearSubmitErrors = _actions.clearSubmitErrors,
    destroy = _actions.destroy,
    focus = _actions.focus,
    initialize = _actions.initialize,
    registerField = _actions.registerField,
    reset = _actions.reset,
    setSubmitFailed = _actions.setSubmitFailed,
    setSubmitSucceeded = _actions.setSubmitSucceeded,
    startAsyncValidation = _actions.startAsyncValidation,
    startSubmit = _actions.startSubmit,
    stopAsyncValidation = _actions.stopAsyncValidation,
    stopSubmit = _actions.stopSubmit,
    submit = _actions.submit,
    touch = _actions.touch,
    unregisterField = _actions.unregisterField,
    untouch = _actions.untouch;
export { arrayInsert, arrayMove, arrayPop, arrayPush, arrayRemove, arrayRemoveAll, arrayShift, arraySplice, arraySwap, arrayUnshift, autofill, blur, change, clearSubmitErrors, destroy, focus, initialize, registerField, reset, setSubmitFailed, setSubmitSucceeded, startAsyncValidation, startSubmit, stopAsyncValidation, stopSubmit, submit, touch, unregisterField, untouch };
